/**
 * @description  L-systems are used to model naturally occurring patterns in nature such as growth of trees, growth of multicellular organisms, fractals etc.
 * by recursively applying a set of simple grammar rules over a set of variables starting with an Axiom.
 * @param {number} numberOfIteration - The initial string of symbols to be used as the axiom.
 * @param {Array<[string, string]>} condition - Array of pairs of strings (The initial string of symbols to be used as the axiom.) to be compared. Length of the array
 * must be not more than 2. Extra elements will be ignored.
 * @returns {string} - The final string of symbols after the specified number of iterations.
 * @ Author: Sarthak Dwivedi
 */
const lSystemGenerator = (numberOfIteration, condition) => {
  const [ruleOne, ruleTwo] = condition;
  let txt = ruleOne[0];
  for (let i = 0; i < numberOfIteration - 1; i++) {
    let newTxt = '';
    for (let j = 0; j < txt.length; j++) {
      let letter = txt.substring(j, j + 1);
      if (letter === ruleOne[0]) {
        newTxt += ruleOne[1];
      } else {
        newTxt += ruleTwo[1];
      }
    }
    txt = `${txt}\n${newTxt}`;
  }
  return txt;
};

// Test case 1 - for 3 iterations
console.log(
  lSystemGenerator(3, [
    ['A', 'ABA'],
    ['B', 'BBB'],
  ])
);;

// -Problem Statement----------;
